
/*
 * This file defines a standard AI personality for the base game. 
 * 
 * It relies on ruleset definition in /rulesets/ to provide
 * standard strategy descriptions and necessary game stat information.
 * 
 * Then it passes control to the main code.
 * 
 */

// You can redefine these paths when you make a customized AI
// for a map or a challenge.
DB_PATH = "/multiplay/skirmish/";
DB_INCLUDES = DB_PATH + "db_includes/";
DB_RULESETS = DB_PATH + "db_rulesets/";
DB_COMMON = DB_PATH + "db_common/";

// please don't touch this line
include(DB_INCLUDES + "_head.js");

////////////////////////////////////////////////////////////////////////////////////////////
// Start the actual personality definition

// the rules in which this personality plays
include(DB_RULESETS + "standard.js");
include(DB_COMMON + "standard_build_order.js");

// variables defining the personality
var subpersonalities = {
	MR: {
		chatalias: "mr",
		weaponPaths: [ // weapons to use; put late-game paths below!
			weaponStats.machineguns, 
			weaponStats.rockets_AT,
			weaponStats.rockets_VTOL, 
			weaponStats.rockets_Arty,		
			weaponStats.AA,			
			weaponStats.rockets_AS,
 			weaponStats.rockets_AA, 
			weaponStats.bombs, 
			weaponStats.fort_MISSILE,
			weaponStats.nexusTech,
		],
		weaponAA: [
			weaponStats.AA,			
		],
		weaponArty: [
			weaponStats.rockets_Arty,
		],
		earlyResearch: [ // fixed research path for the early game
 			"R-Wpn-MG-Damage01",
			"R-Defense-Tower01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-MG-Damage03",
			],
		aaTurrets: [
			"QuadMg1AAGun",		//Hurricane
			"Rocket-Sunburst",	//sunburst
			"QuadRotAAGun",		//whirlwind
			"Missile-LtSAM",	// avenger
			"Missile-HvySAM",	//vindicator
		],
		minTanks: 1, // minimal attack force at game start
		becomeHarder: 3, // how much to increase attack force every 5 minutes
		maxTanks: 18, // maximum for the minTanks value (since it grows at becomeHarder rate)
		minTrucks: 2, // minimal number of trucks around
		minHoverTrucks: 3, // minimal number of hover trucks around
		maxSensors: 2, // number of mobile sensor cars to produce
		minMiscTanks: 1, // number of tanks to start harassing enemy
		maxMiscTanks: 3, // number of tanks used for defense and harass
		vtolness: 65, // the chance % of not making droids when adaptation mechanism chooses vtols
		defensiveness: 65, // same thing for defenses; set this to 100 to enable turtle AI specific code
		maxPower: 700, // build expensive things if we have more than that
		repairAt: 50, // how much % healthy should droid be to join the attack group instead of repairing
		hover: 25, //preference for hover
		hitandrun: false,
		maxECM: 2, // number of ecm tanks to use
		maxRepair: 2, // number of repair trucks to build
		minVTOL: 3,  // minimal attack forece of vtols
		maxVTOL: 18,  // maximum value for mininimal attack forece of vtols
	},
		MC: {
		chatalias: "mc",
		weaponPaths: [
			weaponStats.cannons,
			weaponStats.machineguns, 
			weaponStats.mortars,
 			weaponStats.AA,			
			weaponStats.cannons_AA,
 			weaponStats.bombs, 
			weaponStats.nexusTech,
		],
		weaponAA: [
			weaponStats.AA,			
		],
		weaponArty: [
			weaponStats.mortars,
		],
		earlyResearch: [
			"R-Wpn-MG-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Cannon1Mk1",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-MG-Damage03",
			],
		aaTurrets: [
			"QuadMg1AAGun",		//Hurricane
			"AAGun2Mk1",		//flak cannon
			"QuadRotAAGun",		//whirlwind
		],
		minTanks: 1, becomeHarder: 3, maxTanks: 18,
		minTrucks: 3, minHoverTrucks: 4, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 3,
		vtolness: 65, defensiveness: 65,
		maxPower: 700,
		repairAt: 50,
		hover: 25, //preference for hover
		hitandrun: false,
		maxECM: 2, // number of ecm tanks to use
		maxRepair: 2, // number of repair trucks to build
		minVTOL: 3,  // minimal attack forece of vtols
		maxVTOL: 18,  // maximum value for mininimal attack forece of vtols
	},
	FR: {
		chatalias: "fr",
		weaponPaths: [
			weaponStats.flamers,
			weaponStats.rockets_AT, 
			weaponStats.rockets_VTOL, 
			weaponStats.rockets_Arty,
			weaponStats.rockets_AA,
			weaponStats.rockets_AS, 
			weaponStats.fireMortars,
			weaponStats.bombs, 
			weaponStats.lasers,
			weaponStats.laser_AA, 
			weaponStats.fort_MISSILE,
  			weaponStats.nexusTech,
		],
		weaponAA: [
			weaponStats.rockets_AA,			
		],
		weaponArty: [
			weaponStats.rockets_Arty,
		],
		earlyResearch: [
			"R-Wpn-Flamer-ROF01",
			"R-Vehicle-Prop-Halftracks",
			"R-Struc-PowerModuleMk1",
		],
		aaTurrets: [
			"QuadMg1AAGun",		//Hurricane
			"QuadRotAAGun",		//whirlwind
			"Rocket-Sunburst",	//sunburst
			"Missile-LtSAM",	// avenger
			"AAGunLaser",		//stormbringer
			"Missile-HvySAM",	//vindicator
		],
		minTanks: 1, becomeHarder: 3, maxTanks: 18,
		minTrucks: 3, minHoverTrucks: 4, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 3,
		vtolness: 65, defensiveness: 65,
		maxPower: 700,
		repairAt: 50,
		hover: 75, //preference for hover
		hitandrun: false,
		maxECM: 2, // number of ecm tanks to use
		maxRepair: 2, // number of repair trucks to build
		minVTOL: 3,  // minimal attack forece of vtols
		maxVTOL: 18,  // maximum value for mininimal attack forece of vtols
	},
	FC: {
		chatalias: "fc",
		weaponPaths: [
			weaponStats.flamers, 
			weaponStats.cannons,
			weaponStats.mortars,
			weaponStats.cannons_AA,
			weaponStats.cannons_AS,
			weaponStats.fireMortars,
			weaponStats.bombs, 
			weaponStats.lasers,
			weaponStats.laser_AA,
			weaponStats.nexusTech,
		],
		weaponAA: [
			weaponStats.cannons_AA,			
		],
		weaponArty: [
			weaponStats.mortars,
		],
		earlyResearch: [
			"R-Wpn-Flamer-ROF01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Cannon1Mk1",
			"R-Struc-PowerModuleMk1",
		],
		aaTurrets: [
			"QuadMg1AAGun",		//Hurricane
			"QuadRotAAGun",		//whirlwind
			"AAGun2Mk1",		//flak cannon
			"AAGunLaser",		//stormbringer
		],
		minTanks: 1, becomeHarder: 3, maxTanks: 18,
		minTrucks: 3, minHoverTrucks: 4, maxSensors: 2,
		minMiscTanks: 1, maxMiscTanks: 3,
		vtolness: 65, defensiveness: 65,
		maxPower: 700,
		repairAt: 50,
		hover: 75, //preference for hover
		hitandrun: false,
		maxECM: 2, // number of ecm tanks to use
		maxRepair: 2, // number of repair trucks to build
		minVTOL: 3,  // minimal attack forece of vtols
		maxVTOL: 18,  // maximum value for mininimal attack forece of vtols
	},

};

// this function describes the early build order
// you can rely on personality.chatalias for choosing different build orders for
// different subpersonalities

function buildOrder() {
	var ret = scopeRatings();

	if ( gameTime > 300000 || difficulty === INSANE || isStructureAvailable("A0ComDroidControl") || baseType !== CAMP_CLEAN ) {
	    return buildOrder_StandardFallback();
	}	
	if (personality.chatalias === "fc" || personality.chatalias == "fr") {
		if (buildMinimum(structures.labs, 1)) return true;
		if (buildMinimum(structures.factories, 1)) return true;
		if (buildMinimum(structures.labs, 2)) return true;
		if(ret.land+ret.sea>0) 
			if (buildMinimum(structures.factories, 2)) return true;
		if (buildMinimumDerricks(2)) return true;
		if (buildMinimum(structures.hqs, 1)) return true;
		if (buildMinimum(structures.gens, 2)) return true;
		//if(ret.land+ret.sea>0) 
		//	if (buildMinimum(structures.factories, 3)) return true;
	} else {
		if (buildMinimum(structures.factories, 1)) return true;
		if(ret.land+ret.sea>0) 
			if (buildMinimum(structures.factories, 2)) return true;
		if (buildMinimumDerricks(1)) return true;
		if (buildMinimum(structures.labs, 1)) return true;
		if (buildMinimum(structures.hqs, 1)) return true;
		if(ret.land+ret.sea>0) 
			if (buildMinimum(structures.factories, 3)) return true;
		if (buildMinimum(structures.gens, 2)) return true;
	}
	
	return captureSomeOil();
}
////////////////////////////////////////////////////////////////////////////////////////////
// Proceed with the main code

include(DB_INCLUDES + "_main.js");
